/*******************************************************************************
 * Vicus eBusiness Solutions Version Control
 * @package 	NL-Dutch
 * Description	Dutch language pack for vtiger CRM version 5.3.x
 * @author	$Author: luuk $
 * @version 	$Revision: 1.3 $ $Date: 2011/11/13 14:09:29 $
 * @source	$Source: /var/lib/cvs/vtiger530/Dutch/include/js/nl_nl.lang.js,v $
 * @copyright	Copyright (c)2005-2011 Vicus eBusiness Solutions bv <info@vicus.nl>
 * @license	vtiger CRM Public License Version 1.0 (by definition)
 ********************************************************************************/

	
	var alert_arr = {       DELETE:'Wilt u de geselecteerde records wissen? ',
                                RECORDS:' records?',
                                SELECT:'selecteer ten minste een entiteit',
                           DELETE_ACCOUNT:'Verwijderen van dit account(s) zal tevens gerelateerde Verkoopkansen en Offertes wissen. Weet u zeker dat u wilt doorgaan? ',
                           DELETE_VENDOR:'Verwijderen van deze leverancier(s) zal tevens gerelateerde Inkoop Orders verwijderen. Weet u zeker dat u wilt doorgaan? ',
                                SELECT_MAILID:'Selecteer een mailid',
                                OVERWRITE_EXISTING_ACCOUNT1:'Overschrijven van het bestaande adres met dit geselecteerde account(',
                                OVERWRITE_EXISTING_ACCOUNT2:') adres details?',
				                OVERWRITE_EXISTING_CONTACT1:'Overschrijven van het bestaande adres met dit geselecteerde account(',
                                OVERWRITE_EXISTING_CONTACT2:') adres details?',
                                MISSING_FIELDS:'Verplichte velden niet ingegeven:',
                                NOT_ALLOWED_TO_EDIT:'U bent niet bevoegd dit veld te wijzigen',
                                NOT_ALLOWED_TO_EDIT_FIELDS:'U bent niet bevoegd dit/deze veld(en) te wijzigen',
                                COLUMNS_CANNOT_BE_EMPTY:'Geselecteerde kolommen kunnen niet leeg zijn',
                                CANNOT_BE_EMPTY:' kan niet leeg zijn',
                                CANNOT_BE_NONE:' -geen- waarde niet correct',
                                ENTER_VALID:'Geef een geldig ',
                                SHOULDBE_LESS:' moet kleiner zijn dan ',
                                SHOULDBE_LESS_EQUAL:' moet kleiner of gelijk zijn aan ',
                                SHOULDBE_EQUAL:' moet gelijk zijn aan ',
                                SHOULDBE_GREATER:' moet groter zijn dan ',
                                SHOULDBE_GREATER_EQUAL:' moet groter of gelijk zijn aan ',
                                INVALID:'Foutief ',
                                EXCEEDS_MAX:' groter dan max toegestane limiet ',
                                OUT_OF_RANGE:' ongeldig bereik',
                                SHOULDNOTBE_EQUAL:' moet niet gelijk zijn aan ',
                                PORTAL_PROVIDE_EMAILID:'Geef een geldig Email Id om de Portaal gebruiker te activeren',
                                ADD_CONFIRMATION:'Wilt u het geselecteerde toevoegen ',
                                ACCOUNTNAME_CANNOT_EMPTY:'Account Naam kan niet leeg zijn',
                                CANT_SELECT_CONTACTS:"U kunt geen gerelateerd contact van Lead selecteren",
                                LBL_THIS:'Deze ',
                                DOESNOT_HAVE_MAILIDS:" Geen mail id opgegeven",
                                ARE_YOU_SURE:'Weet u zeker?',
                                DOESNOT_HAVE_AN_MAILID:'" '+"heeft geen Email Id",
                                MISSING_REQUIRED_FIELDS:'Verplichte velden niet ingegeven: ',
                                READONLY:"alleen lezen!",
				SELECT_ATLEAST_ONE_USER:'Selecteer minimaal 1 gebruiker',
                                DISABLE_SHARING_CONFIRMATION:'Weet u zeker delen te deactiveren voor de geselecteerde ',
                                USERS:' gebruiker(s) ?',
                                ENDTIME_GREATER_THAN_STARTTIME:'Eind tijd moet groter zijn dan de begin tijd ',
                                FOLLOWUPTIME_GREATER_THAN_STARTTIME:'Follow-up Tijd moet groter zijn dan de eind tijd ',
                                MISSING_EVENT_NAME:'Gebeurtenis naam niet ingegeven',
                                EVENT_TYPE_NOT_SELECTED:'Gebeurtenis type is niet geselecteerd',
                                CLOSEDATE_CANNOT_BE_EMPTY:'Sluit datum kan niet --leeg-- zijn',
                                SITEURL_CANNOT_BE_EMPTY:'Site Url kanniet --leeg-- zijn',
                                SITENAME_CANNOT_BE_EMPTY:'Site Naam kan niet --leeg-- zijn',
                                LISTPRICE_CANNOT_BE_EMPTY:'Prijzen lijst kan niet --leeg-- zijn',
                                INVALID_LIST_PRICE:'Ongeldige Prijzen Lijst',
                                PROBLEM_ACCESSSING_URL:'Probleem benaderen url: ',
                                CODE:' Code: ',
                                WISH_TO_QUALIFY_MAIL_AS_CONTACT:'Weet u zeker dat u deze Mail als Contact wilt kwalificeren?',
                                SELECT_ATLEAST_ONEMSG_TO_DEL:'Selecteer ten minste 1 bericht om te verwijderen',
                                ERROR:'Fout',
                                FIELD_TYPE_NOT_SELECTED:'Veld Type is niet geselecteerd',
                                SPECIAL_CHARACTERS_NOT_ALLOWED:'Speciale karakters zijn niet toegestaan in het Label veld',
				SPECIAL_CHARACTERS:'Speciale karakters',
                                NOT_ALLOWED:'zijn niet toegestaan. Probeer andere waarden',
                                PICKLIST_CANNOT_BE_EMPTY:'Keuzelijst kan niet leeg zijn',
                                DUPLICATE_VALUES_FOUND:'Dubbele inhoud gevonden',
                                DUPLICATE_MAPPING_ACCOUNTS:'Dubbele mapping voor Accounts!!',
                                DUPLICATE_MAPPING_CONTACTS:'Dubbele mapping voor Contacts!!',
                                DUPLICATE_MAPPING_POTENTIAL:'Dubbele mapping voor Verkoopkansen!!',
                                ERROR_WHILE_EDITING:'Fout bij Wijzigen',
                                CURRENCY_CHANGE_INFO:'Wijzigingen succesvol toegepast',
                             CURRENCY_CONVERSION_INFO:'Gebruikt u Dollar $ als Valuta \n Klik OK om $ te behouden, Annuleer om de valuta conversie waarde te wijzigen.',
                                THE_EMAILID: "Het email id \'",
                                EMAIL_FIELD_INVALID:"\' in het email veld id niet geldig",
                                MISSING_REPORT_NAME:'Rapport Naam leeg',
                                REPORT_NAME_EXISTS:'Rapport naam reeds aanwezig, probeer opnieuw...',
                                WANT_TO_CHANGE_CONTACT_ADDR:'Wilt u het adres wijzigen van de Contacten gerelateerd aan dit Account?',
                                SURE_TO_DELETE:'Weet u zeker dat u wilt verwijderen ?',
				NO_PRODUCT_SELECTED:'Geen product is geselecteerd. Selecteer ten minsten een product',
                                VALID_FINAL_PERCENT:'Geef een geldig kortings percentage',
                                VALID_FINAL_AMOUNT:'Geef een definitief geldige kortings hoeveelheid',
                                VALID_SHIPPING_CHARGE:'Geef een Transport toeslag',
                                VALID_ADJUSTMENT:'Geef een geldige Aanpassing',
                                WANT_TO_CONTINUE:'Wilt u Doorgaan?',
                                ENTER_VALID_TAX:'Geef een geldige BTW waarde',
                                VALID_TAX_NAME:'Geef een BTW naam',
                                CORRECT_TAX_VALUE:'Geef een correcte BTW Waarde',
                                ENTER_POSITIVE_VALUE:'Waarde kan alleen positief zijn',
                                LABEL_SHOULDNOT_EMPTY:'Het BTW label mag niet leeg zijn',
                                NOT_VALID_ENTRY:'geen geldige invoer. Geef een correcte waarde',
                                VALID_DISCOUNT_PERCENT:'Geef een geldig kortings percentage',
                                VALID_DISCOUNT_AMOUNT:'Geef een geldige kortings hoeveelheid',
                                SELECT_TEMPLATE_TO_MERGE:'Selecteer een sjabloon voor de merge',
				SELECTED_MORE_THAN_ONCE:'U heeft de volgende items meerdere malen geselecteerd.',
				YES:'ja',
                                NO:'nee',
                                MAIL:'mail',
				EQUALS:'gelijk aan',
				NOT_EQUALS_TO:'niet gelijk aan',
				STARTS_WITH:'Begint met',
				CONTAINS:'bevat',	
				DOES_NOT_CONTAINS:'bevat niet',
				LESS_THAN:'kleiner dan',
				GREATER_THAN:'groter dan',
				LESS_OR_EQUALS:'kleiner of gelijk',
				GREATER_OR_EQUALS:'groter of gelijk',

				NO_SPECIAL_CHARS:'Speciale Karakters zijn niet toegestaan in de factuur String',
				PLS_SELECT_VALID_FILE:'Selecteer een bestand met de volgende extensies:\n',
                                NO_SPECIAL:'Speciale Karakters zijn niet toegestaan',
				NO_QUOTES:'Quotes (\' ") en + symbolen zijn niet toegestaan ',
				IN_PROFILENAME:' in Profiel Naam',
				IN_GROUPNAME:' in Groep Naam',
				IN_ROLENAME:' in Rol Naam',
                                VALID_TAX_PERCENT:'Geef een geldig BTW percentage',
                                VALID_SH_TAX:'Geef een Transporttoeslag ',
				ROLE_DRAG_ERR_MSG:'U kunt geen Ouder Node onder een Dochter Node plaatsen',
				LBL_DEL:'wis',
				VALID_DATA :' Geef geldige invoer, Probeer opnieuw... ',
                                STDFILTER : 'Standaard Filters',
                                STARTDATE : 'Startdatum',
                                ENDDATE : 'Einddatum',
                                START_DATE_TIME : 'Startdatum & Tijd',
                                START_TIME : 'Start Tijd',
                                DATE_SHOULDNOT_PAST :'Huidige datum & tijd voor Activitieiten met status zoals Geplanned',
                                TIME_SHOULDNOT_PAST :'Huidige tijd voor Activitieiten met status zoals Geplanned',
				LBL_AND : 'En',
				LBL_ENTER_VALID_PORT: 'Geef een geldig poort nummer',
				IN_USERNAME :' in Gebruikersnaam ',
				LBL_ENTER_VALID_NO: 'Geef een geldig nummer',
				LBL_PROVIDE_YES_NO: ' Foutieve waarde.\n Geef Ja of Nee',
				LBL_SELECT_CRITERIA: ' Foutive criteria.\n Selecteer criteria',
				// Added/Updated for vtiger CRM 5.0.4
				OPPORTUNITYNAME_CANNOT_BE_EMPTY:'Potienteel Naam veld kan niet leeg zijn',
                		OVERWRITE_EXISTING_ACCOUNT1:'Wilt u het bestaande adres overschrijven met het geselecteerde Account?(',
                		NAME_DESC:' voor Map Naam & Omschrijving',
                		ENDS_WITH:'eindigd met',
                		SHARED_EVENT_DEL_MSG:'De Gebruiker heeft geen rechten voor het Wijzigen/Wissen van Gedeelde Gebeurtenissen.',
                                                                                                                             

				LBL_WRONG_IMAGE_TYPE: 'Toegestane bestands types voor Contanten - jpeg, png, jpg, pjpeg, x-png of gif-',
				SELECT_MAIL_MOVE: 'Selecteer een Email en verplaats..',
				
				LBL_NOTSEARCH_WITHSEARCH_ALL:'U heeft de zoekfunctie niet gebruikt. Alle records worden gexporteerd van ',
				LBL_NOTSEARCH_WITHSEARCH_CURRENTPAGE:'U heeft niets gezocht. Maar u heeft geselecteerd met de zoek & huidige pagina page opties. De records in de huidige pagina zullen gexporteerd worden van ',
				LBL_NO_DATA_SELECTED:'Geen record geselecteerd. Selecteer ten minste 1 record voor Export',
				LBL_SEARCH_WITHOUTSEARCH_ALL:'U heeft de zoek optie gebruikt maar u heeft geselecteerd zonder zoek & alle opties.\nU kunt [ok] klikken om alle data te exporteren of u klikt [annuleer] om opnieuw te proberen met andere export criteria',
				STOCK_IS_NOT_ENOUGH : 'Voorraad is niet toerijkend',
				INVALID_QTY : 'Ongeldige Hoeveelheid',
				LBL_SEARCH_WITHOUTSEARCH_CURRENTPAGE:'U heeft de zoek optie gebruikt maar u heeft niet geselecteerd zonder zoek & huidige pagina option.\nU kunt [ok] klikken om de huidige pagiba data te exporteren of u klikt [annuleer] om opnieuw te proberen met ander export criteria.',
				LBL_SELECT_COLUMN: ' Kolom niet geldig.\n Seleceer kolom',
				LBL_NOT_ACCESSIBLE : 'Niet Benaderbaar',
				LBL_FILENAME_LENGTH_EXCEED_ERR: 'Bestandsnaam kan niet meer als 255 karakters bevatten',
				LBL_DONT_HAVE_EMAIL_PERMISSION : "U heeft geen permissie voor het Email veld dus kunt u geen email id kiezen",
				LBL_NO_FEEDS_SELECTED: 'Geen Feeds Geselecteerd',
				LBL_SELECT_PICKLIST:'Selecteer tenminste 1 waarde om te wissen',
				LBL_CANT_REMOVE:'U kunt niet alle waarden wissen',

				// Added after 5.0.4 GA
				
				/*For global add/delete in picklist*/
				LBL_GIVE_PICKLIST_VALUE:'Geef een waarde voor de geselecteerde keuzelijst om mee te vervangen',
				LBL_SELECT_ROLE:'Selecteer tenminste 1 rol om de nieuwe waarden toe te voegen',
				LBL_ADD_PICKLIST_VALUE:'Geef tenminste 1 nieuwe waarde om toe te voegen',
				LBL_NO_VALUES_TO_DELETE: "geen waarden om te wissen",

                /* For Duplicate merging feature */
				SAME_GROUPS: 'U dient de records in dezelfde groep te selecteren voor merging',
				ATLEAST_TWO: 'Selecteer tenminste twee records voor merging',
				MAX_THREE: 'U kunt maximaal drie records selecteren',
				//PARENT_RECORD: 'Select a record as parent record',  MergeFields.tpl Line:59
				MAX_RECORDS: 'U kunt maximaal vier records selecteren',
				CON_MANDATORY: 'Selecteer het verplichte veld -Laatste Naam-',
				LE_MANDATORY: 'Selecteer het verplichte velden -Laatste Naam en Bedrijf-',
				ACC_MANDATORY: 'Selecteer het verplichte veld -Account Naam-',
				PRO_MANDATORY: 'Selecteer het verplichte veld -Product Naam-',
				TIC_MANDATORY: 'Selecteer het verplichte veld -Ticket Titel-',
				POTEN_MANDATORY: 'Selecteer het verplichte veld -Verkoopkans Naam-',
				VEN_MANDATORY: 'Selecteer het verplichte veld -Verkoper Naam-',
				DEL_MANDATORY: 'U kunt niet het verplichte veld wissen',
				
				/* For Multi-Currency Support */
			MSG_CHANGE_CURRENCY_REVISE_UNIT_PRICE: 'Unit prijzen van alle valuta zullen worden herzien gebaseerd op de geselecteerde valuta. Weet u zeker?',
				
				Select_one_record_as_parent_record : 'Selecteer 1 record als ouder record',
				RECURRING_FREQUENCY_NOT_PROVIDED : 'Terugkerende frequentie is niet gegeven',
				RECURRING_FREQNECY_NOT_ENABLED : 'Terugkerende frequentie is gegeven, maar is niet geactiveerd',
				/* Added for Documents module */
				NO_SPECIAL_CHARS_DOCS:'Speciale karakters zoals aanhalingstekens, backslash, + symbolen, % en ? zijn niet toegestaan',
				FOLDER_NAME_TOO_LONG:'Mapnaam is te lang. Probeer opnieuw!',
				FOLDERNAME_EMPTY:'De Mapnaam kan niet leeg zijn',
				DUPLICATE_FOLDER_NAME:'Dupliceren van een bestaande Mapnaam. Probeer opnieuw !',
				FOLDER_DESCRIPTION_TOO_LONG:'Omschrijving van de Map is te lang. Probeer opnieuw!',
				NOT_PERMITTED:"U heeft geen permissie voor het uitvoeren van deze toepassing.",		
				
				ALL_FILTER_CREATION_DENIED:'Kan geen CustomView aanmaken met de naam "Alles", Probeer een andere ViewName',
				OPERATION_DENIED:'U heeft geen permissie om deze toepassing uit te voeren',
				EMAIL_CHECK_MSG: 'Deactiveer portaal toegang door het email veld leeg op te slaan',
				IS_PARENT : 'Dit Product heeft Sub Producten, Het is niet toegestaan een Ouder te kiezen voor dit product',
				
				/*global actions on picklist*/
				PICKLIST_CANNOT_BE_EMPTY: 'Selectielijst waarde kan niet leeg zijn',
				DUPLICATE_VALUES_FOUND: 'Dubbele waarden gevonden',
				LBL_NO_ROLES_SELECTED: 'Geen rol is geselecteerd, wilt u doorgaan?',
				LBL_DUPLICATE_FOUND: 'Waarde is reeds aanwezig ',
				LBL_CANNOT_HAVE_EMPTY_VALUE: 'Kan niet vervangen met een lege waarde, om de waarde te wissen kies de wis optie.',
				LBL_DUPLICATE_VALUE_EXISTS: 'Dubbele waarde aanwezig',
				LBL_WANT_TO_DELETE: "Dit wist alle geselecteerde selectielijst waarde(n) voor alle rollen. Wilt u doorgaan? ",
				LBL_DELETE_ALL_WARNING: "Minimaal 1 waarde voor selectielijst nodig",
				LBL_PLEASE_CHANGE_REPLACEMENT: "Verander de vervang waarde; deze is tevens geselecteerd om gewist te worden",
				
				/*layout Editor changes*/
				BLOCK_NAME_CANNOT_BE_BLANK : 'Blok naam kan niet leeg zijn',
				ARE_YOU_SURE_YOU_WANT_TO_DELETE : 'Weet u zeker dat u wilt wissen ?',
				PLEASE_MOVE_THE_FIELDS_TO_ANOTHER_BLOCK : 'Verplaats de velden naar een ander Blok',
				ARE_YOU_SURE_YOU_WANT_TO_DELETE_BLOCK : 'Weet u zeker dat u het Blok wilt wissen?',
				LABEL_CANNOT_NOT_EMPTY : 'Label kan niet leeg zijn',
				LBL_TYPEALERT_1 : 'Sorry, u kunt niet koppelen de',
				LBL_WITH : 'met',
				LBL_TYPEALERT_2 : 'data type. Koppel dezelfde data types.',
				LBL_LENGTHALERT : 'Sorry, u kunt geen velden koppelen met verschillende karakter groten. Koppel de data met dezelfde or meer karakter groten.',
				LBL_DECIMALALERT : 'Sorry, u kunt geen velden koppelen met verschillende decimale posities. Koppel de data met dezelfde of meer decimale posities.',
				FIELD_IS_MANDATORY : 'Verplicht Veld',
				FIELD_IS_ACTIVE : 'Veld is beschikbaar voor gebruik',
				FIELD_IN_QCREATE : 'Aanwezig in Snel Toevoegen',
				FIELD_IS_MASSEDITABLE : 'Beschikbaar voor Massa Wijzigen',	
					
				IS_MANDATORY_FIELD : 'is Verplicht Veld',
				CLOSEDATE_CANNOT_BE_EMPTY : 'Sluitings datum kan niet leeg zijn',
				AMOUNT_CANNOT_BE_EMPTY : 'Aantal kan niet leeg zijn',
				ARE_YOU_SURE : 'Weet u zeker dat u wilt wissen?',
				LABEL_ALREADY_EXISTS : 'Label bestaat reeds. Geef een ander Label',
				LENGTH_OUT_OF_RANGE : 'Lengte van het Blok moet minder als 50 karakters zijn',
				LBL_SELECT_ONE_FILE : 'Selecteer tenminste 1 bestand',
				LBL_UNABLE_TO_ADD_FOLDER : 'Map toevoegen niet mogelijk. Probeer opnieuw.',
				LBL_ARE_YOU_SURE_YOU_WANT_TO_DELETE_FOLDER : 'Weet u zeker dat u deze Map wilt wissen?',
				LBL_ERROR_WHILE_DELETING_FOLDER : 'Fout bij het wissen van de map. Probeer later opnieuw.',
				LBL_FILE_CAN_BE_DOWNLOAD : 'Bestand is beschikbaar voor download',
				LBL_DOCUMENT_LOST_INTEGRITY:'Dit Document is niet beschikbaar. Het wordt gemarkeerd als niet Actief',
				LBL_DOCUMENT_NOT_AVAILABLE : 'Bestand is niet beschikbaar voor download',
				LBL_FOLDER_SHOULD_BE_EMPTY : 'Map moet leeg zijn voor een wis actie!',
				
				LBL_PLEASE_SELECT_FILE_TO_UPLOAD : 'Select het bestand voor de upload.',
				LBL_ARE_YOU_SURE_TO_MOVE_TO : 'Weet u zeker dat u de bestand(en) wilt verplaatsen naar ',
				LBL_FOLDER : ' map',
				LBL_UNABLE_TO_UPDATE : 'Update niet mogelijk! Probeer later opnieuw.',
				LBL_BLANK_REPLACEMENT: "Kan geen lege waarde selecteren als vervanging",
				
				LBL_IMAGE_DELETED : 'Afbeelding Gewist',
				
				/* Tooltip management */
				ERR_FIELD_SELECTION : 'Fouten in de veld selectie',
				
				/* Inventory validation strings */
				NO_LINE_ITEM_SELECTED : 'Geen regel item geselecteerd. Selecteer minimaal een regel item.',
				LINE_ITEM : 'Regel item',
				LIST_PRICE: 'Regel Prijs',
				
				/* Webmails */
				LBL_PRINT_EMAIL : 'Print', 
				LBL_DELETE_EMAIL : 'Verwijder', 
				LBL_DOWNLOAD_ATTACHMENTS : 'Download Bijlage(n)', 
				LBL_QUALIFY_EMAIL : 'Kwalificeer', 
				LBL_FORWARD_EMAIL : 'Doorsturen', 
				LBL_REPLY_TO_SENDER : 'Afzender antwoorden', 
				LBL_REPLY_TO_ALL : 'Antwoorden aan Ieder',
				
				LBL_WIDGET_HIDDEN : 'Widget Verborgen',
				LBL_RESTORE_FROM_PREFERENCES : 'U kunt dit herstellen via uw voorkeuren',
				ERR_HIDING : 'Fout bij verbergen',
				MSG_TRY_AGAIN : 'Probeer opnieuw',
				
				MSG_ENABLE_SINGLEPANE_VIEW : 'Singlepane View geActiveerd',
				MSG_DISABLE_SINGLEPANE_VIEW : 'Singlepane View geDeactiveerd',
				
				MSG_FTP_BACKUP_DISABLED : 'FTP Backup geDeactiveerd',
				MSG_LOCAL_BACKUP_DISABLED : 'Lokale Backup geDeactiveerd',
				MSG_FTP_BACKUP_ENABLED : 'FTP Backup geActiveerd',
				MSG_LOCAL_BACKUP_ENABLED : 'Lokale Backup geActiveerd',
				MSG_CONFIRM_PATH : 'bevestig met de -Pad- details',
				MSG_CONFIRM_FTP_DETAILS : 'bevestig met de -FTP- details',
				
				START_PERIOD_END_PERIOD_CANNOT_BE_EMPTY : 'Start periode of Eind periode kunnen niet leeg zijn',
				
				/* added to fix i18n issues with home page*/
				LBL_ADD: 'Toevoegen ',
				Module: 'Module',
				DashBoard: 'DashBoard',
				RSS: 'RSS',
				Default: 'Standaard',
				Notebook: 'Notebook',
				SPECIAL_CHARS:'\\ / < > + \' " '
			};
	

